ApiGuardConfig class

Configuration of the api guard. Can be placed in the analysis_options.yaml file.

Constructors

ApiGuardConfig({required Set<String> include, required Set<String> exclude, List<String> entryPoints = const [], required bool generateBadge, List<MagnitudeOverride> magnitudeOverrides = const []})
ApiGuardConfig.defaultConfig()
factory
ApiGuardConfig.fromYaml(File analysisOptionsFile)
factory

Properties

entryPoints List<String>
Entry points for the API analysis.
final
exclude Set<String>
Files to exclude from the API documentation.
final
generateBadge bool
Whether to generate a badge for the version.
final
hashCode int
The hash code for this object.
no setterinherited
include Set<String>
Files to include in the API documentation.
final
magnitudeOverrides List<MagnitudeOverride>
Overrides for the magnitude of changes.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({bool? generateBadge, Set<String>? include, Set<String>? exclude, List<String>? entryPoints, List<MagnitudeOverride>? magnitudeOverrides}) ApiGuardConfig
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

load(Directory root) ApiGuardConfig
Loads the configuration from the analysis_options.yaml file in the provided root directory. Returns the default configuration if the file does not exist or if the api_guard section is missing.