doc_comparator/api_change library

Classes

ApiChange
A change description in the API that belongs to a specific component.
ComponentApiChange
A change that belongs to a specific component. A component can be a class, mixin, interface or typedef.
ConstructorApiChange
ConstructorParameterApiChange
MetaApiChange
MethodApiChange
A change that belongs to a specific method of a component or a top-level function.
MethodParameterApiChange
ParameterApiChange
Base class for parameter changes to share magnitude logic
PropertyApiChange
A change that belongs to a specific property of a component.

Enums

ApiChangeMagnitude
The type of change that was detected in the API. A patch change is a change that does not break the API. A minor change is a change that adds new features to the API or introduces backwards-compatible changes. A major change is a change that breaks the API or removes features.
ApiChangeOperation