MethodApiChange class

A change that belongs to a specific method of a component or a top-level function.

Inheritance

Constructors

MethodApiChange({required DocComponent component, required ApiChangeOperation operation, required DocMethod method, DocType? newType, String? annotation, String? changedValue})

Properties

annotation String?
finalinherited
changedValue String?
finalinherited
component DocComponent
finalinherited
hashCode int
The hash code for this object.
no setterinherited
method DocMethod
final
newType DocType?
final
operation ApiChangeOperation
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getMagnitude() ApiChangeMagnitude
override
isFunctionChange() bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
overrideMagnitude(ApiChangeMagnitude magnitude) → void
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited