DocComponent class

Available extensions
Annotations
  • @JsonSerializable.new()

Constructors

DocComponent({required String name, required String description, required List<DocConstructor> constructors, required List<DocProperty> properties, required List<DocMethod> methods, String? filePath, String? entryPoint, DocComponentType type = DocComponentType.classType, String? aliasedType, List<String> annotations = const [], List<String> superClasses = const [], List<String> superClassPackages = const [], List<String> interfaces = const [], List<String> mixins = const [], List<String> typeParameters = const []})
const
DocComponent.fromJson(Map<String, dynamic> json)
factory
DocComponent.meta({required String name, required String description, String? filePath})
factory

Properties

aliasedType String?
final
annotations List<String>
final
constructors List<DocConstructor>
final
description String
final
entryPoint String?
The entry point that exposed this component (optional).
final
filePath String?
The relative path to the file that defines this component.
final
genericName String
no setter
hashCode int
The hash code for this object.
no setterinherited
interfaces List<String>
final
methods List<DocMethod>
final
mixins List<String>
final
name String
final
properties List<DocProperty>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
superClasses List<String>
final
superClassPackages List<String>
final
type DocComponentType
final
typeParameters List<String>
final

Methods

compareTo(DocComponent newComponent) List<ApiChange>

Available on DocComponent, provided by the DocComponentApiChangesExt extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited