usage property

  1. @override
String get usage
override

Generates a string displaying usage information for this command.

This includes usage for the command's arguments as well as a list of subcommands, if there are any.

Implementation

@override
String get usage {
  return "${super.usage}\n\nCalculates the next version based on API changes between versions.\nUses the current package version from the base file.\n";
}