version/workspace_utils library

Classes

WorkspaceInfo
WorkspacePackage
WorkspaceTagFormat
Tag naming scheme for workspace packages.

Functions

detectWorkspace(Directory root) WorkspaceInfo?
Detects if the given directory is a Dart workspace root
getWorkspacePackages(WorkspaceInfo workspace) List<WorkspacePackage>
Gets all workspace packages with their names and directories
packageHasChanges(String packagePath, String baseRef, String newRef, Directory gitRoot) Future<bool>
Checks if a package directory has changes between two git refs
sortPackagesTopologically(List<WorkspacePackage> packages) List<WorkspacePackage>
Returns the workspace packages sorted in topological order so that a package always appears before any other package that depends on it. Packages with no intra-workspace dependencies come first.