WorkspaceVersionResult class

Constructors

WorkspaceVersionResult({required Map<String, VersionResult> packageResults, required Map<String, Version> packageVersions})

Properties

hashCode int
The hash code for this object.
no setterinherited
packageResults Map<String, VersionResult>
final
packageVersions Map<String, Version>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited