VersionConstraintCallbacks class
Callbacks for creating version constraint change events.
Constructors
- VersionConstraintCallbacks({required ApiChange onMinIncrease(String version, String previousVersion), required ApiChange onMinDecrease(String version, String previousVersion), required ApiChange onMaxIncrease(String version, String previousVersion), required ApiChange onMaxDecrease(String version, String previousVersion)})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- onMaxDecrease → ApiChange Function(String version, String previousVersion)
-
final
- onMaxIncrease → ApiChange Function(String version, String previousVersion)
-
final
- onMinDecrease → ApiChange Function(String version, String previousVersion)
-
final
- onMinIncrease → ApiChange Function(String version, String previousVersion)
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited