Cache class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getApiFileForRef(String repoPath, String ref, String dartRelativePath)
→ File
-
Gets the path for an API file cached for a specific git ref and dart root
-
getCacheDir()
→ Directory
-
Gets the root cache directory
-
getRepositoryCacheDir(String repoPath)
→ Directory
-
Gets the cache directory for a specific repository
-
getWorktreeDir(String repoPath, String ref)
→ Directory
-
Gets the worktree directory for a specific git ref
Sanitizes the ref name to be safe for use in file paths
-
hasApiFileForRef(String repoPath, String ref, String dartRelativePath)
→ bool
-
-
listCachedRefs(String repoPath)
→ List<String>
-
Lists all cached refs for a repository
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
retrieveApiFile(String repoPath, String ref, String dartRelativePath)
→ Future<String?>
-
Retrieves API documentation for a specific git ref and dart root
-
storeApiFile(String repoPath, String ref, String dartRelativePath, String content)
→ Future<void>
-
Stores API documentation for a specific git ref and dart root
-
toString()
→ String
-
A string representation of this object.
inherited