PubspecUtils class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
getAllDependencies(
String pubspecContent) → Map< String, dynamic> - Gets all dependencies (including dev_dependencies) from a pubspec file
-
getPackageName(
String pubspecContent) → String -
getVersion(
String pubspecContent) → Version -
setVersion(
File pubspec, Version version) → Future< void> -
updateWorkspaceDependency(
File pubspec, String packageName, Version newVersion) → Future< void> - Updates a workspace dependency version while maintaining constraint format Updates both dependencies and dev_dependencies sections