usage property
Generates a string displaying usage information for this command.
This includes usage for the command's arguments as well as a list of subcommands, if there are any.
Implementation
@override
String get usage {
return "${super.usage}\n\nCalculates the next version for each package in a Dart workspace based on API changes.\nOnly packages with changes compared to the base ref will be versioned.\nTags are created in format: {package}/v{version} by default, configurable via --tag-format.\nDependencies between workspace packages are automatically updated.\n";
}