version/workspace_utils library

Functions

detectWorkspace(Directory root) WorkspaceInfo?
Detects if the given directory is a Dart workspace root
getWorkspacePackages(WorkspaceInfo workspace) List<WorkspacePackage>
Gets all workspace packages with their names and directories
packageHasChanges(String packagePath, String baseRef, String newRef, Directory gitRoot) Future<bool>
Checks if a package directory has changes between two git refs